@@ -8,13 +8,18 @@
  */
 
 package org.gnu.gnome;
+
 import org.gnu.gdk.Pixbuf;
-import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
+import org.gnu.javagnome.Handle;
+
 /**
  * The About widget dialog window is designed to pop up from the
  * About button on an application menu. Its purpose is to standardize
  * the form and content.
+ * 
+ * @deprecated
+ * @see org.gnu.gtk.AboutDialog
  */
 public class About extends org.gnu.gtk.Dialog {
 
