@@ -8,12 +8,11 @@
  */
 
 package org.gnu.gnome;
-import org.gnu.glib.Flags;
+
+import org.gnu.javagnome.Flags;
+
 public class DateEditFlags extends Flags 
 {
-    /****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
     static final private int _SHOW_TIME = 1 << 0;
     static final public org.gnu.gnome.DateEditFlags SHOW_TIME = new org.gnu.gnome.DateEditFlags (
         _SHOW_TIME);
@@ -79,8 +78,5 @@ public class DateEditFlags extends Flags
         return (value_ & other.value_) == other.value_;
     }
 
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
 }
 
