@@ -12,19 +12,22 @@ package org.gnu.gnome;
 import java.util.Vector;
 
 import org.gnu.glib.EventMap;
+import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.FontPickerEvent;
 import org.gnu.gnome.event.FontPickerListener;
 import org.gnu.gtk.Button;
 import org.gnu.gtk.Widget;
-import org.gnu.gtk.event.GtkEventType;
+import org.gnu.javagnome.Handle;
+
 /**
  * The FontPicker widget is a button that, when selected, presents
  * a window that enables the user to select from among the many
  * available fonts.
  * 
  * @deprecated
+ * @see org.gnu.gtk.FontButton
  */
 public class FontPicker extends Button {
 	/**
@@ -42,7 +45,7 @@ public class FontPicker extends Button {
 	/**
 	 * Construct a FontPicker using a handle to a native resource.
 	 */
-	public FontPicker(int handle) {
+	public FontPicker(Handle handle) {
 		super(handle);
 	}
 
@@ -104,10 +107,10 @@ public class FontPicker extends Button {
 	 * @see #setMode(FontPickerMode)
 	 */
 	public Widget getUserWidget() {
-		int hndl = gnome_font_picker_uw_get_widget(getHandle());
-		if (0 == hndl)
+		Handle hndl = gnome_font_picker_uw_get_widget(getHandle());
+		if (null == hndl)
 			return null;
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
@@ -166,7 +169,6 @@ public class FontPicker extends Button {
 	// Event handling
 	//////////////////////////////////////////////////////
 
-	// TODO: events doen't seem to be propogated.
 	/**
 	 * Register an object to handle FontPicker events.
 	 * @see org.gnu.gnome.event.FontPickerListener
@@ -220,8 +222,8 @@ public class FontPicker extends Button {
 		return cls;
 	}
 
-	public GtkEventType getEventType(String signal) {
-		GtkEventType et = evtMap.getEventType(signal);
+	public EventType getEventType(String signal) {
+		EventType et = evtMap.getEventType(signal);
 		if (et == null) et = super.getEventType(signal);
 		return et;
 	}
@@ -239,27 +241,21 @@ public class FontPicker extends Button {
 		anEvtMap.addEvent("font_set", "handleFontSet", FontPickerEvent.Type.FONT_SET, FontPickerListener.class);
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_font_picker_get_type();
-	native static final protected int gnome_font_picker_new();
-	native static final protected void gnome_font_picker_set_title(int gfp, String title);
-	native static final protected String gnome_font_picker_get_title(int gfp);
-	native static final protected int gnome_font_picker_get_mode(int gfp);
-	native static final protected void gnome_font_picker_set_mode(int gfp, int mode);
-	native static final protected void gnome_font_picker_fi_set_use_font_in_label(
-		int gfp,
-		boolean use_font_in_label,
-		int size);
-	native static final protected void gnome_font_picker_fi_set_show_size(int gfp, boolean showSize);
-	native static final protected void gnome_font_picker_uw_set_widget(int gfp, int widget);
-	native static final protected int gnome_font_picker_uw_get_widget(int gfp);
-	native static final protected String gnome_font_picker_get_font_name(int gfp);
-	native static final protected boolean gnome_font_picker_set_font_name(int gfp, String fontname);
-	native static final protected String gnome_font_picker_get_preview_text(int gfp);
-	native static final protected void gnome_font_picker_set_preview_text(int gfp, String text);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gnome_font_picker_new();
+	native static final protected void gnome_font_picker_set_title(Handle gfp, String title);
+	native static final protected String gnome_font_picker_get_title(Handle gfp);
+	native static final protected int gnome_font_picker_get_mode(Handle gfp);
+	native static final protected void gnome_font_picker_set_mode(Handle gfp, int mode);
+	native static final protected void gnome_font_picker_fi_set_use_font_in_label(Handle gfp,
+		boolean use_font_in_label, int size);
+	native static final protected void gnome_font_picker_fi_set_show_size(Handle gfp, boolean showSize);
+	native static final protected void gnome_font_picker_uw_set_widget(Handle gfp, Handle widget);
+	native static final protected Handle gnome_font_picker_uw_get_widget(Handle gfp);
+	native static final protected String gnome_font_picker_get_font_name(Handle gfp);
+	native static final protected boolean gnome_font_picker_set_font_name(Handle gfp, String fontname);
+	native static final protected String gnome_font_picker_get_preview_text(Handle gfp);
+	native static final protected void gnome_font_picker_set_preview_text(Handle gfp, String text);
+
 }
