@@ -8,12 +8,11 @@
  */
 
 package org.gnu.gnome;
-import org.gnu.glib.Enum;
+
+import org.gnu.javagnome.Enum;
+
 public class FontPickerMode extends Enum 
 {
-    /****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
     static final private int _PIXMAP = 0;
     static final public org.gnu.gnome.FontPickerMode PIXMAP = new org.gnu.gnome.FontPickerMode (
         _PIXMAP);
@@ -82,8 +81,5 @@ public class FontPickerMode extends Enum
         return (value_ & other.value_) == other.value_;
     }
 
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
 }
 
