@@ -9,7 +9,7 @@
 
 package org.gnu.gnome;
 
-import org.gnu.glib.Handle;
+import org.gnu.javagnome.Handle;
 
 public class Gnome 
 {
@@ -27,7 +27,7 @@ public class Gnome
 	
 	/**
 	 * Flush the accelerator definitions into the application specific configuration
-	 * file ~/.gnome/accels/<appid>
+	 * file ~/.gnome/accels/&lt;appid&gt;
 	 */
 	public static void syncAccelerators() {
 		gnome_accelerators_sync();
@@ -36,8 +36,8 @@ public class Gnome
 
     static
     {
-		System.loadLibrary ("gtkjni-2.5");
-        System.loadLibrary ("gnomejni-2.9");
+		System.loadLibrary ("gtkjni-2.7");
+        System.loadLibrary ("gnomejni-2.11");
     }
 
     native static final protected Handle gnome_master_client ();
