@@ -8,11 +8,13 @@
  */
 
 package org.gnu.gnome;
+
 import org.gnu.glib.GObject;
-import org.gnu.glib.Handle;
 import org.gnu.gtk.AccelGroup;
 import org.gnu.gtk.Menu;
 import org.gnu.gtk.Widget;
+import org.gnu.javagnome.Handle;
+
 /**
  * @deprecated
  */
