@@ -8,12 +8,11 @@
  */
 
 package org.gnu.gnome;
-import org.gnu.glib.Enum;
+
+import org.gnu.javagnome.Enum;
+
 public class SaveStyle extends Enum 
 {
-    /****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
     static final private int _GLOBAL = 0;
     static final public org.gnu.gnome.SaveStyle GLOBAL = new org.gnu.gnome.SaveStyle (_GLOBAL);
     static final private int _LOCAL = 1;
@@ -23,9 +22,7 @@ public class SaveStyle extends Enum
     static final private org.gnu.gnome.SaveStyle[] theInterned = new org.gnu.gnome.SaveStyle[] 
     {
         GLOBAL, LOCAL, BOTH 
-    }
-
-;
+    };
     static private java.util.Hashtable theInternedExtras;
     static final private org.gnu.gnome.SaveStyle theSacrificialOne = new org.gnu.gnome.SaveStyle (0);
     static public org.gnu.gnome.SaveStyle intern (int value) 
@@ -74,8 +71,5 @@ public class SaveStyle extends Enum
         return (value_ & other.value_) == other.value_;
     }
 
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
 }
 
