@@ -8,8 +8,10 @@
  */
 
 package org.gnu.gnome;
-import org.gnu.glib.Boxed;
-public class Url extends Boxed 
+
+import org.gnu.javagnome.Struct;
+
+public class Url extends Struct 
 {
     /**
      * This method displays the given URL in he appropriate viewer.  The
