@@ -1,7 +1,7 @@
 /*
  * Java-Gnome Bindings Library
  *
- * Copyright 1998-2002 the Java-Gnome Team, all rights reserved.
+ * * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
  *
  * The Java-Gnome Team Members:
  *   Jean Van Wyk <jeanvanwyk@iname.com>
@@ -14,16 +14,17 @@
 
 package org.gnu.gnome.event;
 
+import org.gnu.glib.EventType;
 import org.gnu.gtk.event.GtkEvent;
-import org.gnu.gtk.event.GtkEventType;
 
 /**
  * An event represeting action by a {@link org.gnu.gnome.FontPicker} widget.
  * 
  * @deprecated
+ * @see org.gnu.gtk.events.FontButtonEvent
  */
 public class FontPickerEvent extends GtkEvent {
-    public static class Type extends GtkEventType{
+    public static class Type extends EventType{
 	private Type(int id, String name){
 	    super(id, name);
 	}
